@@ -19,14 +19,15 @@ from io import StringIO
 from edk2toolext.environment.extdeptypes.nuget_dependency import NugetDependency
 from edk2toollib.utility_functions import RunCmd
 
-OPEN_SOURCE_INITIATIVE_URL = "https://opensource.org/licenses/"
-LICENSE_TYPE_SUPPORTED = {
-    "BSD2": OPEN_SOURCE_INITIATIVE_URL + "BSD-2-Clause",
-    "BSD3": OPEN_SOURCE_INITIATIVE_URL + "BSD-3-Clause",
-    "APACHE2": OPEN_SOURCE_INITIATIVE_URL + "Apache-2.0",
-    "MSPL": OPEN_SOURCE_INITIATIVE_URL + "MS-PL",  # Microsoft Public License
-    "MIT": OPEN_SOURCE_INITIATIVE_URL + "MIT",
-    "BSDpP": OPEN_SOURCE_INITIATIVE_URL + "BSDplusPatent",  # BSD + Patent
+# Use associated SPDX license Identifier
+# https://learn.microsoft.com/en-us/nuget/reference/nuspec#license
+LICENSE_IDENTIFIER_SUPPORTED = {
+    "BSD2": "BSD-2-Clause",
+    "BSD3": "BSD-3-Clause",
+    "APACHE2": "Apache-2.0",
+    "MSPL": "MS-PL",  # Microsoft Public License
+    "MIT": "MIT",
+    "BSD2pP": "BSD-2-Clause-Patent",  # BSD2 + Patent
 }
 
 
@@ -44,7 +45,7 @@ class NugetSupport(object):
         <authors></authors>
 
         <!-- Optional elements -->
-        <licenseUrl></licenseUrl>
+        <license></license>
         <releaseNotes></releaseNotes>
         <projectUrl></projectUrl>
         <copyright></copyright>
@@ -115,7 +116,7 @@ class NugetSupport(object):
     def SetBasicData(self, authors, license, project, description, server, copyright):
         """Set basic data in the config data."""
         self.ConfigData["author_string"] = authors
-        self.ConfigData["license_url"] = license
+        self.ConfigData["license"] = license
         self.ConfigData["project_url"] = project
         self.ConfigData["description_string"] = description
         self.ConfigData["server_url"] = server
@@ -128,6 +129,29 @@ class NugetSupport(object):
 
         self.ConfigChanged = True
 
+    def UpdateLicensePath(self, licensepath):
+        """Update license in the config data.
+
+        Update license in the config data with an absolute path to a license
+        to pack.
+        """
+        self.ConfigData["license"] = licensepath
+
+    def IsValidLicense(self):
+        """Returns whether the License is valid."""
+        license = self.ConfigData["license"]
+
+        if license in LICENSE_IDENTIFIER_SUPPORTED.values():
+            return True
+
+        if not os.path.isabs(license) or not os.path.isfile(license):
+            return False
+
+        if os.path.basename(license).lower() not in ["license.txt", "license.md"]:
+            return False
+
+        return True
+
     def UpdateCopyright(self, copyright):
         """Update copyright in the config data."""
         self.ConfigData["copyright_string"] = copyright
@@ -183,11 +207,11 @@ class NugetSupport(object):
 
     def _MakeNuspecXml(self, ContentDir, ReleaseNotesText=None):
         package = etree.fromstring(NugetSupport.NUSPEC_TEMPLATE_XML)
+        package.attrib["xmlns"] = "http://schemas.microsoft.com/packaging/2010/07/nuspec.xsd"
         meta = package.find("./metadata")
         meta.find("id").text = self.Name
         meta.find("version").text = self.NewVersion
         meta.find("authors").text = self.ConfigData["author_string"]
-        meta.find("licenseUrl").text = self.ConfigData["license_url"]
         meta.find("projectUrl").text = self.ConfigData["project_url"]
         meta.find("description").text = self.ConfigData["description_string"]
         meta.find("copyright").text = self.ConfigData["copyright_string"]
@@ -198,6 +222,18 @@ class NugetSupport(object):
         f.set("target", self.Name)
         f.set("src", ContentDir + "\\**\\*")
 
+        # Add appropriate attribute to the license element depending on if the
+        # license is custom or not. If the license is custom, add a new file
+        # element pointing at the license
+        if os.path.isfile(self.ConfigData["license"]):
+            meta.find("license").text = os.path.basename(self.ConfigData["license"])
+            meta.find("license").attrib["type"] = "file"
+            f = etree.Element("file", attrib={"src": self.ConfigData["license"], "target": ""})
+            files.append(f)
+        else:
+            meta.find("license").text = self.ConfigData["license"]
+            meta.find("license").attrib["type"] = "expression"
+
         if (ReleaseNotesText is not None):
             logging.debug("Make Nuspec Xml - ReleaseNotesText is not none.")
             #
@@ -329,10 +365,11 @@ def GatherArguments():
         parser.add_argument('--Author', dest="Author", help="<Required> Author string for publishing", required=True)
         parser.add_argument("--ProjectUrl", dest="Project", help="<Required> Project Url", required=True)
         g = parser.add_mutually_exclusive_group(required=True)
-        g.add_argument('--CustomLicenseUrl', dest="LicenseUrl",
-                       help="<Optional> http url for custom license file.  Can use LicenseType for standard licenses")
-        g.add_argument('--LicenseType', dest="LicenseType",
-                       choices=LICENSE_TYPE_SUPPORTED.keys(), help="Standard Licenses")
+        g.add_argument('--CustomLicense', dest="LicenseIdentifier", action="store_true",
+                       help="<Optional> Specify that a file will be provided as the License during the pack command. \
+                            Can use License Identifier for standard licenses")
+        g.add_argument('--LicenseIdentifier', dest="LicenseIdentifier",
+                       choices=LICENSE_IDENTIFIER_SUPPORTED.keys(), help="Standard Licenses")
         parser.add_argument('--Description', dest="Description",
                             help="<Required> Description of package.", required=True)
         parser.add_argument("--FeedUrl", dest="FeedUrl",
@@ -355,6 +392,9 @@ def GatherArguments():
         parser.add_argument('--ApiKey', dest="ApiKey",
                             help="<Optional>Api key to use. Default is 'VSTS' which will invoke interactive login",
                             default="VSTS")
+        parser.add_argument('--CustomLicensePath', dest="CustomLicensePath", default=None,
+                            help="<Optional> If CustomLicense set in `new` phase, provide absolute path of License \
+                            File to pack. Does not override existing valid license.")
 
     elif (args.op.lower() == "push"):
         parser.add_argument("--ConfigFilePath", dest="ConfigFilePath",
@@ -410,11 +450,14 @@ def main():
 
         nu = NugetSupport(Name=args.Name)
 
-        # license
-        license_url = args.LicenseUrl
-        if (args.LicenseType is not None):
-            license_url = LICENSE_TYPE_SUPPORTED[args.LicenseType]
-        nu.SetBasicData(args.Author, license_url, args.Project, args.Description, args.FeedUrl, args.Copyright)
+        # Support Standard License or Custom License
+        # Custom License path provided during pack operation
+        if args.LicenseIdentifier is True:
+            license = "Use --CustomLicensePath in Pack command to set this"
+        else:
+            license = LICENSE_IDENTIFIER_SUPPORTED[args.LicenseIdentifier]
+
+        nu.SetBasicData(args.Author, license, args.Project, args.Description, args.FeedUrl, args.Copyright)
         nu.LogObject()
         ret = nu.ToConfigFile(ConfigFilePath)
         return ret
@@ -440,6 +483,16 @@ def main():
         os.mkdir(TempOutDir)
 
         nu = NugetSupport(ConfigFile=args.ConfigFilePath)
+
+        if not nu.IsValidLicense() and args.CustomLicensePath is not None:
+            nu.UpdateLicensePath(args.CustomLicensePath)
+
+        if not nu.IsValidLicense():
+            logging.critical("Invalid License")
+            logging.critical("    Verify custom license file name is license.txt or license.md")
+            logging.critical("    Verify custom license file path is in absolute format and valid")
+            raise Exception("Invalid License. Verify valid name and that path is absolute and valid")
+
         if (args.Copyright is not None):
             nu.UpdateCopyright(args.Copyright)
         if (len(args.Tags) > 0):
